{% if GOOGLE_ANALYTICS %}
    <!-- Google Analytics -->
    <script type="text/javascript">

        var _gaq = _gaq || [];
        _gaq.push(['_setAccount', '{{ GOOGLE_ANALYTICS }}']);
        _gaq.push(['_trackPageview']);

        (function () {
            var ga = document.createElement('script');
            ga.type = 'text/javascript';
            ga.async = true;
            ga.src = ('https:' == document.location.protocol ? 'https://ssl' : 'http://www') + '.google-analytics.com/ga.js';
            var s = document.getElementsByTagName('script')[0];
            s.parentNode.insertBefore(ga, s);
        })();
    </script>
    <!-- End Google Analytics Code -->
{% endif %}
{% if GOOGLE_ANALYTICS_UNIVERSAL %}
    <!-- Google Analytics Universal -->
    <script type="text/javascript">
        (function(i,s,o,g,r,a,m){i['GoogleAnalyticsObject']=r;i[r]=i[r]||function(){
        (i[r].q=i[r].q||[]).push(arguments)},i[r].l=1*new Date();a=s.createElement(o),
        m=s.getElementsByTagName(o)[0];a.async=1;a.src=g;m.parentNode.insertBefore(a,m)
        })(window,document,'script','//www.google-analytics.com/analytics.js','ga');

        ga('create', '{{ GOOGLE_ANALYTICS_UNIVERSAL }}', '{{ GOOGLE_ANALYTICS_UNIVERSAL_PROPERTY }}');
        ga('send', 'pageview');
    </script>
    <!-- End Google Analytics Universal Code -->
{% endif %}
{% if GOOGLE_ANALYTICS_V4 %}
    <!-- Google tag (gtag.js) -->
    <script async type="text/javascript" src="https://www.googletagmanager.com/gtag/js?id={{ GOOGLE_ANALYTICS_V4 }}"></script>
    <script type="text/javascript">
        window.dataLayer = window.dataLayer || [];
        function gtag(){dataLayer.push(arguments);}
        gtag('js', new Date());

        gtag('config', '{{ GOOGLE_ANALYTICS_V4 }}');
    </script>
    <!-- End Google tag (gtag.js) -->
{% endif %}
