{% extends "base.html" %}

{% block title -%}
    Articles &mdash; {{ super() }}
{%- endblock %}

{% block breadcrumbs %}
    {% if DISPLAY_BREADCRUMBS %}
        <ol class="breadcrumb">
            <li><a href="{{ SITE_ROOT_URL | default('/') }}" title="{{ SITENAME }}"><span class="fa fa-home fa-lg"></span></a></li>
          {% if MENUITEMS_2_AT %}
            <li><a href="{{ SITEURL -}} / {{- MENUITEMS_2_AT_LINK }}" title="{{ MENUITEMS_2_AT }}">{{ MENUITEMS_2_AT }}</a></li>
          {% endif %}
            <li class="active">Articles</li>
        </ol>
    {% endif %}
{% endblock %}

{% block content %}
    {% if articles %}
        {% for article in (articles_page.object_list if articles_page else articles) %}
            <article>
                <h2><a href="{{ SITEURL -}} / {{- article.url }}">{{ article.title }}</a></h2>
                {% if DISPLAY_ARTICLE_INFO_ON_INDEX %}
                    <div class="well well-sm">
                        {% include "includes/article_info.html" %}
                    </div>
                {% endif %}
                <div class="summary">{{ article.summary }}
                    {% include 'includes/comment_count.html' %}
                    <a class="btn btn-default btn-xs" href="{{ SITEURL -}} / {{- article.url }}">more ...</a>
                </div>
            </article>
            <hr/>
        {% endfor %}
    {% endif %}

    {% include 'includes/pagination.html' %}
{% endblock content %}
