@import url('https://fonts.googleapis.com/css?family=Merriweather:300,400|Open+Sans|Source+Code+Pro');


/*
Tipue Search 7.1
Copyright (c) 2019 Tipue
Tipue Search is released under the MIT License
http://www.tipue.com/search
*/


/* search box */


#tipue_search_input
{
     float: left;
     font: 15px 'Open Sans', sans-serif;
     color: #333;     
     -webkit-font-smoothing: antialiased;
     -moz-osx-font-smoothing: grayscale;
     width: 230px;
     background-color: #f3f3f3;
     border: none;
     padding: 9px 0 10px 18px;
     height: 56px;
     border-radius: 3px;
     -moz-appearance: none;
     -webkit-appearance: none;
     box-sizing: border-box;
     box-shadow: none;
     outline: 0;
     margin: 0;
}
#tipue_search_input:-webkit-autofill,
#tipue_search_input:-webkit-autofill:hover, 
#tipue_search_input:-webkit-autofill:focus
{
     -webkit-box-shadow: 0 0 0px 1000px #f3f3f3 inset;
}
.tipue_search_button
{
     position: relative;
     float: left;
     width: 49px;
     height: 56px;
     margin-left: -3px;
     background-color: #f3f3f3;
     border: none;
     border-top-right-radius: 3px;
     border-bottom-right-radius: 3px;
     box-sizing: border-box;
     cursor: pointer;
     outline: 0;
}
.tipue_search_icon
{
     float: left;
     font: 24px/1 'Open Sans', sans-serif;
     -webkit-font-smoothing: antialiased;
     -moz-osx-font-smoothing: grayscale;
     color: #333;
     transform: rotate(-45deg);
     -moz-appearance: none;
     -webkit-appearance: none;
     box-sizing: border-box;
     box-shadow: none;
     outline: 0;
     margin: -1px 0 0 16px;
}
.tipue_search_group:after
{
     content: "";
     display: table;
     clear: both;
}


/* search results */


#tipue_search_content
{
     max-width: 100%;
     margin: 0;
}
.tipue_search_content_title
{
     font: 300 32px/1.4 Merriweather, serif;
     color: #111;
}
.tipue_search_content_title a
{
     color: #111;
     text-decoration: none;
}
.tipue_search_content_title a:hover
{
     border-bottom: 1px solid #333;
}
.tipue_search_result
{
     padding-top: 27px;
}
#tipue_search_results_count, .tipue_search_content_debug
{
     font: 13px/1.5 'Source Code Pro', monospace;
     text-transform: uppercase;
     color: #999;
     -webkit-font-smoothing: antialiased;
     -moz-osx-font-smoothing: grayscale;
}
#tipue_search_results_count
{
     padding-top: 9px;
}
.tipue_search_content_url, .tipue_search_note, .tipue_search_related, #tipue_search_error, #tipue_search_replace
{
     font: 300 16px/1.4 Merriweather, serif;
     color: #666;
     padding-top: 7px;
     word-wrap: break-word;
     hyphens: auto;
}
.tipue_search_content_url a, .tipue_search_note a, .tipue_search_related a, #tipue_search_replace a, #tipue_search_replace a:hover
{
     color: #339e41;
     text-decoration: none;
}
.tipue_search_content_url a:hover, .tipue_search_note a:hover, .tipue_search_related a:hover
{
     color: #666;
}
#tipue_search_replace, .tipue_search_related
{
     margin-top: 7px;
}
#tipue_search_error
{
     color: #333;
     margin-top: 17px;
}
.tipue_search_content_text
{
     font: 300 18px/1.6 Merriweather, serif;
     color: #333;
     word-wrap: break-word;
     hyphens: auto;
     margin-top: 9px;
}
.tipue_search_content_bold
{
     font-weight: 400;
     color: #333;
}
.tipue_search_content_debug
{
     margin: 7px 0 2px 0;
}


/* images */


.tipue_search_image
{
     padding: 17px 0 6px 0;
}
.tipue_search_img
{
     width: 100%;
     max-width: 330px;
     height: auto;
     transition: 0.5s;
     border-radius: 2px;
}
.tipue_search_img:hover
{
     opacity: 0.9;
}
#tipue_search_zoom_text
{
     font: 12px/1.7 'Source Code Pro', monospace;
     color: #ccc;
     text-transform: uppercase;
     letter-spacing: 1px;
     padding-top: 9px;
}
#tipue_search_zoom_text a
{
     color: #ccc;
     text-decoration: none;
     border-bottom: 2px solid #f7f7f7;
}
#tipue_search_zoom_text a:hover
{
     border: 0;
}
.tipue_search_image_zoom
{
     cursor: pointer;     
}
#tipue_search_image_modal
{
     display: none;
     position: fixed;
     z-index: 1000;
     left: 0;
     top: 0;
     width: 100%;
     height: 100%;
     overflow: auto;
     background-color: rgba(0, 0, 0, 0.9);
}
.tipue_search_image_close
{
     position: absolute;
     top: 0;
     right: 0;
     font: 22px/1 'Source Code Pro', monospace;
     color: #ccc;
     padding: 25px 30px;
     cursor: pointer;
}
.tipue_search_image_block
{
     margin: 0 auto;
     max-width: 900px;
     padding: 73px 30px 30px 30px;
     box-sizing: border-box;
     color: #fff;
}
#tipue_search_zoom_img
{
     max-width: 100%;
     height: auto;
}

#tipue_search_zoom_text, .tipue_search_zoom_options
{
     padding-top: 9px;
}


/* footer */


#tipue_search_foot
{
     margin: 51px 0 21px 0;
}
#tipue_search_foot_boxes
{
     font: 14px 'Source Code Pro', sans-serif;
     text-transform: uppercase;
     color: #333;
     padding: 0;
     margin: 0;
     cursor: pointer;
}
#tipue_search_foot_boxes li
{
     display: inline;
     list-style: none;
     margin: 0;
     padding: 0;
}
#tipue_search_foot_boxes li a
{
     background-color: #f7f7f7;
     color: #666;
     padding: 10px 17px 11px 17px;
     border-radius: 3px;
     margin-right: 7px;
     text-decoration: none;
     text-align: center;
     transition: 0.3s;
}
#tipue_search_foot_boxes li.current
{
     background: #252525;
     color: #ccc;
     padding: 10px 17px 11px 17px;
     border-radius: 3px;
     margin-right: 7px;
     text-align: center;
}
#tipue_search_foot_boxes li a:hover
{
     background: #252525;
     color: #ccc;
}

