{% extends "base.html" %}

{% block title -%}
    404 Error &mdash; {{ super() }}
{%- endblock %}

{% block breadcrumbs %}
    {% if DISPLAY_BREADCRUMBS %}
    <ol class="breadcrumb">
        <li><a href="{{ SITE_ROOT_URL | default('/') }}" title="{{ SITENAME }}"><span class="fa fa-home fa-lg"></span></a></li>
      {% if MENUITEMS_2_AT %}
        <li><a href="{{ SITEURL -}} / {{- MENUITEMS_2_AT_LINK }}" title="{{ MENUITEMS_2_AT }}">{{ MENUITEMS_2_AT }}</a></li>
      {% endif %}
        <li class="active">404 Error</li>
    </ol>
    {% endif %}
{% endblock %}

{% block content %}
    <section id="content">
        <article>
            <header class="entry-header">
                <h1>404: Page Not Found</h1>
            </header>
            <div class="entry-content">
                <p>Oops, we're lost...</p>
                <p>You're tried to land on a page that doesn't really exist.</p>
                <p>Go back to <a href="{{ SITE_ROOT_URL | default('/') }}">home</a> and try again?</p>
            </div>
        </article>
    </section>
{% endblock %}
